"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
const express_1 = __importDefault(require("express"));
const utils_1 = __importDefault(require("../utils"));
const HTTPError_1 = __importDefault(require("../HTTPError"));
const Email_1 = __importDefault(require("../Email"));
const moment_1 = __importDefault(require("moment"));
const xss_filters_1 = __importDefault(require("xss-filters"));
let router = express_1.default.Router();
router.get('/', (req, res) => {
    res.render('index', {
        title: 'homepage',
        additional_navbar_classes: 'do-anim'
    });
});
router.get('/team', (req, res) => {
    res.render('team', {
        title: 'team'
    });
});
router.get('/progetto-thelist', (req, res) => {
    res.render('progetto', {
        title: 'progetto TheList'
    });
});
router.get('/affitta-un-posto', (req, res) => {
    res.render('affitta', {
        title: 'affitta un posto'
    });
});
router.post('/affitta-un-posto', utils_1.default.requiredParameters("POST", [
    "name",
    "surname",
    "email",
    "date",
    "time",
    "captcha",
    "text"
]), async (req, res) => {
    const name = xss_filters_1.default.inHTMLData(req.body.name), surname = xss_filters_1.default.inHTMLData(req.body.surname), email = xss_filters_1.default.inHTMLData(req.body.email), date = xss_filters_1.default.inHTMLData(req.body.date), time = xss_filters_1.default.inHTMLData(req.body.time), text = xss_filters_1.default.inHTMLData(req.body.text), c = req.body.captcha;
    let verify = await utils_1.default.verifyCaptcha(process.env.CAPTCHA_KEY, c);
    if (!verify)
        return new HTTPError_1.default('invalid_captcha', 400);
    let mail = new Email_1.default({
        filename: `affitta.html`,
        subject: 'Affitta un posto - nuova richiesta',
        variables: {
            name,
            surname,
            email,
            date: moment_1.default(date).format('DD/MM/YYYY'),
            time,
            text
        }
    });
    mail.send()
        .then(success => {
        res.json(true);
    })
        .catch(err => {
        console.log(err);
        return HTTPError_1.default.GENERIC_ERROR.toResponse(res);
    });
});
module.exports = router;
