import {
    createTransport,
    SendMailOptions,
    Transport
} from 'nodemailer'
import {
    readFile
} from 'fs-extra'
import utils from './utils';
import path from 'path';

export default class Email{

    #options: MailOptions & SendMailOptions;
    #mail_path: string = path.resolve(`${__dirname}/../../mails`);
    #transporter: Transport;

    constructor(options: MailOptions){

        this.#options = options;
        this.#transporter = createTransport({
            host: 'ssl0.ovh.net',
            port: 465 ,
            secure: true, // true for 465, false for other ports
            auth: {
              user: process.env.EMAIL_ACCOUNT!,
              pass: process.env.EMAIL_PASSWORD!
          }
        })

    }

    async send(): Promise<any> {

        let html;
            
        if(this.#options.filename)
            html = Buffer.from(await readFile(`${this.#mail_path}/${this.#options.filename!}`)).toString('utf-8');
        else
            html = this.#options.html;

        if(Object.keys(this.#options.variables!).length > 0)
            html = utils.tokenize(html, this.#options.variables!);
        
        return await this.#transporter.sendMail({

            from: '"TheList website" <postmaster@emilianomaccaferri.com>',
            to: process.env.THELIST_EMAIL!,
            subject: this.#options.subject,
            html

        })

    }

}
export interface MailOptions extends SendMailOptions {

    subject: string,
    variables: {[key: string]: any},
    html?: string,
    filename?: string,

}