import express from 'express';
import utils from '../utils';
import HTTPError from '../HTTPError';
import { AxiosError } from 'axios'
import Email from '../Email';
import moment from 'moment';
import xss from 'xss-filters';

let router = express.Router();

router.get('/', (req: express.Request, res: express.Response) => {

    res.render('index', {
    
        title: 'homepage',
        additional_navbar_classes: 'do-anim'
        
    })

})

router.get('/team', (req: express.Request, res: express.Response) => {

    res.render('team', {
    
        title: 'team'
        
    })

})
router.get('/progetto-thelist', (req: express.Request, res: express.Response) => {

    res.render('progetto', {
    
        title: 'progetto TheList'

    })

})

router.get('/affitta-un-posto', (req: express.Request, res: express.Response) => {

    res.render('affitta', {
    
        title: 'affitta un posto'
    
    })

})

router.post('/affitta-un-posto', utils.requiredParameters("POST", [
        "name",
        "surname",
        "email",
        "date",
        "time",
        "captcha",
        "text"
    ]), async(req: express.Request, res: express.Response) => {

    const name = xss.inHTMLData(req.body.name as string),
          surname = xss.inHTMLData(req.body.surname as string),
          email = xss.inHTMLData(req.body.email as string),
          date = xss.inHTMLData(req.body.date as string),
          time = xss.inHTMLData(req.body.time as string),
          text = xss.inHTMLData(req.body.text as string),
          c = req.body.captcha as string;
    
    let verify = await utils.verifyCaptcha(process.env.CAPTCHA_KEY!, c);   
    if(!verify)
        return new HTTPError('invalid_captcha', 400);

    let mail = new Email({
        filename: `affitta.html`,
        subject: 'Affitta un posto - nuova richiesta',
        variables: {
            name,
            surname,
            email,
            date: moment(date).format('DD/MM/YYYY'),
            time,
            text
        }
    });

    mail.send()
        .then(success => {

            res.json(true);

        })
        .catch(err => {

            console.log(err);
            
            return HTTPError.GENERIC_ERROR.toResponse(res);
        
        })

})

export = router;